password

package
v0.0.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package password provides utilities for hashing and verifying passwords.

The hashing algorithm can be set in the configuration file. The default algorithm is bcrypt, but others like argon2id can be used as well.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HashPassword

func HashPassword(password string) (string, error)

HashPassword hashes the provided password using the configured algorithm.

func VerifyPasswordMatch

func VerifyPasswordMatch(hashedPassword, password string) (bool, error)

VerifyPasswordMatch checks if the hashed password matches the provided password.

Types

type Argon2idParams

type Argon2idParams struct {
	// contains filtered or unexported fields
}

Jump to