Documentation
¶
Index ¶
Constants ¶
const EMAIL_OTP_LENGTH = 8
EMAIL_OTP_LENGTH defines the length of the OTP to be generated for sending in any kind of email.
Variables ¶
This section is empty.
Functions ¶
func NewAlphaNumericOTP ¶
NewAlphaNumericOTP generates an Alphanumeric OTP of the specified length.
Use Case: This function can be used to generate OTPs for two-factor authentication (2FA), password resets, or any other scenario where a short-lived code is required for verification.
func VerifyAlphaNumericOTP ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.