Documentation
¶
Overview ¶
Package password provides utilities for hashing and verifying passwords.
The hashing algorithm can be set in the configuration file. The default algorithm is bcrypt, but others like argon2id can be used as well.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HashPassword ¶
HashPassword hashes the provided password using the configured algorithm.
func VerifyPasswordMatch ¶
VerifyPasswordMatch checks if the hashed password matches the provided password.
Types ¶
type Argon2idParams ¶
type Argon2idParams struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.